@@ -25,7 +25,7 @@ class ExhaustiveSearch(StructureEstimator):
             Note that pandas converts each column containing `numpy.NaN`s to dtype `float`.)
 
         scoring_method: Instance of a `StructureScore`-subclass (`K2Score` is used as default)
-            An instance of `K2Score`, `BDeuScore`, or `BicScore`.
+            An instance of `K2Score`, `BDeuScore`, `BicScore` or 'AICScore'.
             This score is optimized during structure estimation by the `estimate`-method.
 
         state_names: dict (optional)
