@@ -1,20 +1,21 @@
 #!/usr/bin/env python
-from itertools import permutations
 from collections import deque
+from itertools import permutations
 
 import networkx as nx
 from tqdm.auto import trange
 
+from pgmpy.base import DAG
 from pgmpy.estimators import (
-    StructureScore,
-    StructureEstimator,
-    K2Score,
-    ScoreCache,
+    AICScore,
     BDeuScore,
     BDsScore,
     BicScore,
+    K2Score,
+    ScoreCache,
+    StructureEstimator,
+    StructureScore,
 )
-from pgmpy.base import DAG
 from pgmpy.global_vars import SHOW_PROGRESS
 
 
@@ -86,7 +87,7 @@ class HillClimbSearch(StructureEstimator):
             - set([(Y, X) for (X, Y) in model.edges()])
         )
 
-        for (X, Y) in potential_new_edges:
+        for X, Y in potential_new_edges:
             # Check if adding (X, Y) will create a cycle.
             if not nx.has_path(model, Y, X):
                 operation = ("+", (X, Y))
@@ -103,7 +104,7 @@ class HillClimbSearch(StructureEstimator):
                         yield (operation, score_delta)
 
         # Step 2: Get all legal operations for removing edges
-        for (X, Y) in model.edges():
+        for X, Y in model.edges():
             operation = ("-", (X, Y))
             if (operation not in tabu_list) and ((X, Y) not in fixed_edges):
                 old_parents = model.get_parents(Y)
@@ -114,7 +115,7 @@ class HillClimbSearch(StructureEstimator):
                 yield (operation, score_delta)
 
         # Step 3: Get all legal operations for flipping edges
-        for (X, Y) in model.edges():
+        for X, Y in model.edges():
             # Check if flipping creates any cycles
             if not any(
                 map(lambda path: len(path) > 2, nx.all_simple_paths(model, X, Y))
@@ -165,7 +166,7 @@ class HillClimbSearch(StructureEstimator):
         ----------
         scoring_method: str or StructureScore instance
             The score to be optimized during structure estimation.  Supported
-            structure scores: k2score, bdeuscore, bdsscore, bicscore. Also accepts a
+            structure scores: k2score, bdeuscore, bdsscore, bicscore, aicscore. Also accepts a
             custom score, but it should be an instance of `StructureScore`.
 
         start_dag: DAG instance
@@ -233,6 +234,7 @@ class HillClimbSearch(StructureEstimator):
             "bdeuscore": BDeuScore,
             "bdsscore": BDsScore,
             "bicscore": BicScore,
+            "aicscore": AICScore,
         }
         if (
             (
@@ -241,7 +243,7 @@ class HillClimbSearch(StructureEstimator):
             )
         ) and (not isinstance(scoring_method, StructureScore)):
             raise ValueError(
-                "scoring_method should either be one of k2score, bdeuscore, bicscore, bdsscore, or an instance of StructureScore"
+                "scoring_method should either be one of k2score, bdeuscore, bicscore, bdsscore, aicscore, or an instance of StructureScore"
             )
 
         if isinstance(scoring_method, str):
