@@ -10,7 +10,7 @@ class StructureScore(BaseEstimator):
     def __init__(self, data, **kwargs):
         """
         Abstract base class for structure scoring classes in pgmpy. Use any of the derived classes
-        K2Score, BDeuScore, or BicScore. Scoring classes are
+        K2Score, BDeuScore, BicScore or AICScore. Scoring classes are
         used to measure how well a model is able to describe the given data set.
 
         Parameters
@@ -353,3 +353,69 @@ class BicScore(StructureScore):
         score -= 0.5 * log(sample_size) * num_parents_states * (var_cardinality - 1)
 
         return score
+
+
+class AICScore(StructureScore):
+    def __init__(self, data, **kwargs):
+        """
+        Class for Bayesian structure scoring for BayesianNetworks with
+        Dirichlet priors.  The AIC score ("Akaike Information Criterion) is a log-likelihood score with an
+        additional penalty for network complexity, to avoid overfitting.  The
+        `score`-method measures how well a model is able to describe the given
+        data set.
+
+        Parameters
+        ----------
+        data: pandas DataFrame object
+            dataframe object where each column represents one variable.
+            (If some values in the data are missing the data cells should be set to `numpy.NaN`.
+            Note that pandas converts each column containing `numpy.NaN`s to dtype `float`.)
+
+        state_names: dict (optional)
+            A dict indicating, for each variable, the discrete set of states (or values)
+            that the variable can take. If unspecified, the observed values in the data set
+            are taken to be the only possible states.
+
+        complete_samples_only: bool (optional, default `True`)
+            Specifies how to deal with missing data, if present. If set to `True` all rows
+            that contain `np.Nan` somewhere are ignored. If `False` then, for each variable,
+            every row where neither the variable nor its parents are `np.NaN` is used.
+            This sets the behavior of the `state_count`-method.
+
+        References
+        ---------
+        [1] Koller & Friedman, Probabilistic Graphical Models - Principles and Techniques, 2009
+        Section 18.3.4-18.3.6 (esp. page 802)
+        [2] AM Carvalho, Scoring functions for learning Bayesian networks,
+        http://www.lx.it.pt/~asmc/pub/talks/09-TA/ta_pres.pdf
+        """
+        super(AICScore, self).__init__(data, **kwargs)
+
+    def local_score(self, variable, parents):
+        'Computes a score that measures how much a \
+        given variable is "influenced" by a given list of potential parents.'
+
+        var_states = self.state_names[variable]
+        var_cardinality = len(var_states)
+        state_counts = self.state_counts(variable, parents)
+        sample_size = len(self.data)
+        num_parents_states = float(state_counts.shape[1])
+
+        counts = np.asarray(state_counts)
+        log_likelihoods = np.zeros_like(counts, dtype=float)
+
+        # Compute the log-counts
+        np.log(counts, out=log_likelihoods, where=counts > 0)
+
+        # Compute the log-conditional sample size
+        log_conditionals = np.sum(counts, axis=0, dtype=float)
+        np.log(log_conditionals, out=log_conditionals, where=log_conditionals > 0)
+
+        # Compute the log-likelihoods
+        log_likelihoods -= log_conditionals
+        log_likelihoods *= counts
+
+        score = np.sum(log_likelihoods)
+        score -= num_parents_states * (var_cardinality - 1)
+
+        return score
