@@ -357,13 +357,10 @@ class VariableElimination(Inference):
                 var_int_map = {var: i for i, var in enumerate(model_reduced.nodes())}
             einsum_expr = []
             for index, phi in enumerate(factors):
-                if not set(reshape_indexes[index]) == {1}:
-                    einsum_expr.append(
-                        (phi.values[reduce_indexes[index]]).reshape(
-                            reshape_indexes[index]
-                        )
-                    )
-                    einsum_expr.append([var_int_map[var] for var in phi.variables])
+                einsum_expr.append(
+                    (phi.values[reduce_indexes[index]]).reshape(reshape_indexes[index])
+                )
+                einsum_expr.append([var_int_map[var] for var in phi.variables])
             result_values = contract(
                 *einsum_expr, [var_int_map[var] for var in variables], optimize="greedy"
             )
