@@ -1327,7 +1327,8 @@ class BayesianNetwork(DAG):
 
     def save(self, filename, filetype="bif"):
         """
-        Writes the model to a file.
+        Writes the model to a file. Plese avoid using any special characters or
+        spaces in variable or state names.
 
         Parameters
         ----------
@@ -1367,19 +1368,23 @@ class BayesianNetwork(DAG):
             writer.write_xmlbif(filename=filename)
 
     @staticmethod
-    def load(filename, filetype="bif"):
+    def load(filename, filetype="bif", **kwargs):
         """
-        Writes the model to a file.
+        Read the model from a file.
 
         Parameters
         ----------
         filename: str
-            The path along with the filename where to write the file.
+            The path along with the filename where to read the file.
 
         filetype: str (default: bif)
-            The format in which to write the model to file. Can be one of
+            The format of the model file. Can be one of
             the following: bif, uai, xmlbif.
 
+        kwargs: kwargs
+            Any additional arguments for the reader class or get_model method.
+            Please refer the file format class for details.
+
         Examples
         --------
         >>> from pgmpy.utils import get_example_model
@@ -1394,8 +1399,18 @@ class BayesianNetwork(DAG):
         if filetype == "bif":
             from pgmpy.readwrite import BIFReader
 
-            reader = BIFReader(path=filename)
-            return reader.get_model()
+            if "n_jobs" in kwargs:
+                n_jobs = kwargs["n_jobs"]
+            else:
+                n_jobs = -1
+
+            if "state_name_type" in kwargs:
+                state_name_type = kwargs["state_name_type"]
+            else:
+                state_name_type = str
+
+            reader = BIFReader(path=filename, n_jobs=n_jobs)
+            return reader.get_model(state_name_type=state_name_type)
 
         elif filetype == "uai":
             from pgmpy.readwrite import UAIReader
