@@ -1,26 +1,27 @@
-import re
 import collections
-from string import Template
+import re
+from copy import copy
 from itertools import product
+from string import Template
 
 import numpy as np
 from joblib import Parallel, delayed
 from pyparsing import (
-    Word,
-    alphanums,
-    Suppress,
-    Optional,
     CharsNotIn,
     Group,
-    nums,
-    ZeroOrMore,
     OneOrMore,
+    Optional,
+    Suppress,
+    Word,
+    ZeroOrMore,
+    alphanums,
     cppStyleComment,
+    nums,
     printables,
 )
 
-from pgmpy.models import BayesianNetwork
 from pgmpy.factors.discrete import TabularCPD
+from pgmpy.models import BayesianNetwork
 
 
 class BIFReader(object):
@@ -99,7 +100,7 @@ class BIFReader(object):
         """
         A method that returns variable grammar
         """
-        # Defining a expression for valid word
+        # Defining an expression for valid word
         word_expr = Word(alphanums + "_" + "-")
         word_expr2 = Word(initChars=printables, excludeChars=["{", "}", ",", " "])
         name_expr = Suppress("variable") + word_expr + Suppress("{")
@@ -120,7 +121,7 @@ class BIFReader(object):
 
         property_expr = (
             Suppress("property") + CharsNotIn(";") + Suppress(";")
-        )  # Creating a expr to find property
+        )  # Creating an expr to find property
 
         return name_expr, variable_state_expr, property_expr
 
@@ -450,7 +451,7 @@ class BIFWriter(object):
         """
         network_template = Template("network $name {\n}\n")
         # property tag may or may not be present in model,and since no of properties
-        # can be more than one , will replace them accoriding to format otherwise null
+        # can be more than one, will replace them according to format otherwise null
         variable_template = Template(
             """variable $name {
     type discrete [ $no_of_states ] { $states };
@@ -459,15 +460,26 @@ $properties}\n"""
         property_template = Template("    property $prop ;\n")
         # $variable_ here is name of variable, used underscore for clarity
         probability_template = Template(
-            """probability ( $variable_$seprator_$parents ) {
+            """probability ( $variable_$separator_$parents ) {
     table $values ;
 }\n"""
         )
+
+        conditional_probability_template_total = Template(
+            """probability ( $variable_$separator_$parents ) {
+$values
+}\n"""
+        )
+
+        conditional_probability_template = Template("""    ( $state ) $values;\n""")
+
         return (
             network_template,
             variable_template,
             property_template,
             probability_template,
+            conditional_probability_template_total,
+            conditional_probability_template,
         )
 
     def __str__(self):
@@ -479,6 +491,8 @@ $properties}\n"""
             variable_template,
             property_template,
             probability_template,
+            conditional_probability_template_total,
+            conditional_probability_template,
         ) = self.BIF_templates()
         network = ""
         network += network_template.substitute(name=self.network_name)
@@ -503,15 +517,32 @@ $properties}\n"""
         for var in sorted(variables):
             if not self.variable_parents[var]:
                 parents = ""
-                seprator = ""
+                separator = ""
+                cpd = ", ".join(map(str, self.tables[var]))
+                network += probability_template.substitute(
+                    variable_=var, separator_=separator, parents=parents, values=cpd
+                )
             else:
-                parents = ", ".join(self.variable_parents[var])
-                seprator = " | "
-            cpd = ", ".join(map(str, self.tables[var]))
-            network += probability_template.substitute(
-                variable_=var, seprator_=seprator, parents=parents, values=cpd
-            )
+                parents_str = ", ".join(self.variable_parents[var])
+                separator = " | "
+                cpd = self.model.get_cpds(var)
+                cpd_values_transpose = cpd.get_values().T
 
+                parent_states = product(
+                    *[cpd.state_names[var] for var in cpd.variables[1:]]
+                )
+                all_cpd = ""
+                for index, state in enumerate(parent_states):
+                    all_cpd += conditional_probability_template.substitute(
+                        state=", ".join(map(str, state)),
+                        values=", ".join(map(str, cpd_values_transpose[index, :])),
+                    )
+                network += conditional_probability_template_total.substitute(
+                    variable_=var,
+                    separator_=separator,
+                    parents=parents_str,
+                    values=all_cpd,
+                )
         return network
 
     def get_variables(self):
