@@ -3,6 +3,7 @@ from .PomdpX import PomdpXReader, PomdpXWriter
 from .XMLBeliefNetwork import XBNReader, XBNWriter
 from .UAI import UAIReader, UAIWriter
 from .BIF import BIFReader, BIFWriter
+from .NET import NETReader, NETWriter
 
 __all__ = [
     "ProbModelXMLReader",
@@ -17,4 +18,6 @@ __all__ = [
     "UAIWriter",
     "BIFReader",
     "BIFWriter",
+    "NETReader",
+    "NETWriter",
 ]
