@@ -1,16 +1,15 @@
 import itertools
-from collections import defaultdict, namedtuple
+from collections import namedtuple
 
 import networkx as nx
 import numpy as np
 import pandas as pd
+from joblib import Parallel, delayed
 from tqdm.auto import tqdm
 
 from pgmpy.factors import factor_product
 from pgmpy.global_vars import SHOW_PROGRESS
-from pgmpy.models import BayesianNetwork
-from pgmpy.models import DynamicBayesianNetwork as DBN
-from pgmpy.models import MarkovChain, MarkovNetwork
+from pgmpy.models import BayesianNetwork, MarkovChain, MarkovNetwork
 from pgmpy.sampling import BayesianModelInference, _return_samples
 from pgmpy.utils.mathext import sample_discrete, sample_discrete_maps
 
@@ -37,6 +36,7 @@ class BayesianModelSampling(BayesianModelInference):
         seed=None,
         show_progress=True,
         partial_samples=None,
+        n_jobs=-1,
     ):
         """
         Generates sample(s) from joint distribution of the bayesian network.
@@ -59,6 +59,9 @@ class BayesianModelSampling(BayesianModelInference):
             A pandas dataframe specifying samples on some of the variables in the model. If
             specified, the sampling procedure uses these sample values, instead of generating them.
 
+        n_jobs: int (default: -1)
+            The number of CPU cores to use. Default uses all cores.
+
         Returns
         -------
         sampled: pandas.DataFrame
@@ -94,7 +97,6 @@ class BayesianModelSampling(BayesianModelInference):
         for node in pbar:
             if show_progress and SHOW_PROGRESS:
                 pbar.set_description(f"Generating for node: {node}")
-
             # If values specified in partial_samples, use them. Else generate the values.
             if (partial_samples is not None) and (node in partial_samples.columns):
                 sampled[node] = partial_samples.loc[:, node].values
@@ -105,13 +107,14 @@ class BayesianModelSampling(BayesianModelInference):
                 if evidence:
                     evidence_values = np.vstack([sampled[i] for i in evidence])
 
-                    state_to_index, index_to_weight = self.pre_compute_reduce_maps(
-                        variable=node
-                    )
                     unique, inverse = np.unique(
                         evidence_values.T, axis=0, return_inverse=True
                     )
-                    weight_index = np.array([state_to_index[tuple(u)] for u in unique])[
+                    unique = [tuple(u) for u in unique]
+                    state_to_index, index_to_weight = self.pre_compute_reduce_maps(
+                        variable=node, state_combinations=unique, n_jobs=n_jobs
+                    )
+                    weight_index = np.array([state_to_index[u] for u in unique])[
                         inverse
                     ]
                     sampled[node] = sample_discrete_maps(
@@ -242,7 +245,13 @@ class BayesianModelSampling(BayesianModelInference):
         return sampled
 
     def likelihood_weighted_sample(
-        self, evidence=[], size=1, include_latents=False, seed=None, show_progress=True
+        self,
+        evidence=[],
+        size=1,
+        include_latents=False,
+        seed=None,
+        show_progress=True,
+        n_jobs=-1,
     ):
         """
         Generates weighted sample(s) from joint distribution of the bayesian
@@ -267,6 +276,9 @@ class BayesianModelSampling(BayesianModelInference):
         show_progress: boolean
             Whether to show a progress bar of samples getting generated.
 
+        n_jobs: int (default: -1)
+            The number of CPU cores to use. Default uses all cores.
+
         Returns
         -------
         sampled: A pandas.DataFrame
@@ -322,12 +334,13 @@ class BayesianModelSampling(BayesianModelInference):
             if evidence:
                 evidence_values = np.vstack([sampled[i] for i in evidence])
 
-                state_to_index, index_to_weight = self.pre_compute_reduce_maps(
-                    variable=node
-                )
                 unique, inverse = np.unique(
                     evidence_values.T, axis=0, return_inverse=True
                 )
+                unique = [tuple(u) for u in unique]
+                state_to_index, index_to_weight = self.pre_compute_reduce_maps(
+                    variable=node, state_combinations=unique, n_jobs=n_jobs
+                )
                 weight_index = np.array([state_to_index[tuple(u)] for u in unique])[
                     inverse
                 ]
@@ -424,14 +437,14 @@ class GibbsSampling(MarkovChain):
         for var in self.variables:
             other_vars = [v for v in self.variables if var != v]
             other_cards = [self.cardinalities[v] for v in other_vars]
-            cpds = [cpd for cpd in model.cpds if var in cpd.scope()]
-            prod_cpd = factor_product(*cpds)
             kernel = {}
-            scope = set(prod_cpd.scope())
+            factors = [cpd.to_factor() for cpd in model.cpds if var in cpd.scope()]
+            factor = factor_product(*factors)
+            scope = set(factor.scope())
             for tup in itertools.product(*[range(card) for card in other_cards]):
                 states = [State(v, s) for v, s in zip(other_vars, tup) if v in scope]
-                prod_cpd_reduced = prod_cpd.to_factor().reduce(states, inplace=False)
-                kernel[tup] = prod_cpd_reduced.values / sum(prod_cpd_reduced.values)
+                reduced_factor = factor.reduce(states, inplace=False)
+                kernel[tup] = reduced_factor.values / sum(reduced_factor.values)
             self.transition_models[var] = kernel
 
     def _get_kernel_from_markov_model(self, model):
