@@ -1,11 +1,14 @@
 import itertools
+import math
+import os
 from warnings import warn
 
-import numpy as np
 import networkx as nx
+import numpy as np
+from joblib import Parallel, delayed
 
-from pgmpy.inference import Inference
 from pgmpy import HAS_PANDAS
+from pgmpy.inference import Inference
 from pgmpy.utils import _check_1d_array_object, _check_length_equal
 
 if HAS_PANDAS:
@@ -68,7 +71,49 @@ class BayesianModelInference(Inference):
 
         return cached_values
 
-    def pre_compute_reduce_maps(self, variable):
+    @staticmethod
+    def _reduce(variable_cpd, variable_evid, sc_values):
+        """
+        Method to compute values of the `variable_cpd` when it it reduced on
+        `variable_evid` with states `sc_values`. This is a stripped down
+        version DiscreteFactor.reduce to only compute the values for faster
+        runtime.
+
+        Parameters
+        ----------
+        variable_cpd: Instance of pgmpy.factors.discrete.TabularCPD
+            The CPD that will be reduced.
+
+        variable_evid: list
+            List of variable name that need to be reduced.
+
+        sc_values: list
+            list of list of states (corresponding to variable_evid) to which to
+            reduce the CPD.
+
+        Returns
+        -------
+        list: List of np.array with each element representing the reduced
+                values correponding to the states in sc_values.
+        """
+        return_values = []
+        for sc in sc_values:
+            sc = list(zip(variable_evid, sc))
+            try:
+                values = [
+                    (var, variable_cpd.get_state_no(var, state_name))
+                    for var, state_name in sc
+                ]
+            except KeyError:
+                values = sc
+            slice_ = [slice(None)] * len(variable_cpd.variables)
+            for var, state in values:
+                var_index = variable_cpd.variables.index(var)
+                slice_[var_index] = state
+            return_values.append(variable_cpd.values[tuple(slice_)])
+        return return_values
+
+    def pre_compute_reduce_maps(self, variable, state_combinations=None, n_jobs=-1):
         """
         Get probability array-maps for a node as function of conditional dependencies
 
@@ -80,6 +125,12 @@ class BayesianModelInference(Inference):
         variable: Bayesian Model Node
             node of the Bayesian network
 
+        state_combinations: list (default=None)
+            List of tuple of state combinations for which to compute the reductions maps.
+
+        n_jobs: int (default: -1)
+            The number of CPU cores to use. By default uses all.
+
         Returns
         -------
         dict: dictionary with probability array-index for node as function of conditional dependency values,
@@ -88,21 +139,33 @@ class BayesianModelInference(Inference):
         variable_cpd = self.model.get_cpds(variable)
         variable_evid = variable_cpd.variables[:0:-1]
 
-        state_combinations = [
-            tuple(sc)
-            for sc in itertools.product(
-                *[range(self.cardinality[var]) for var in variable_evid]
-            )
-        ]
-        weights_list = np.array(
-            [
-                variable_cpd.reduce(
-                    list(zip(variable_evid, sc)), inplace=False, show_warnings=False
-                ).values
-                for sc in state_combinations
+        if state_combinations is None:
+            state_combinations = [
+                tuple(sc)
+                for sc in itertools.product(
+                    *[range(self.cardinality[var]) for var in variable_evid]
+                )
             ]
+
+        # Comptue batch sizes and call _reduce in parallel.
+        if n_jobs == -1:
+            n_jobs = os.cpu_count()
+        batch_size = math.ceil(len(state_combinations) / n_jobs)
+
+        weights_list = Parallel(n_jobs=n_jobs, prefer="threads")(
+            delayed(BayesianModelInference._reduce)(
+                variable_cpd,
+                variable_evid,
+                state_combinations[
+                    (batch_size * i) : min(
+                        batch_size * (i + 1), len(state_combinations)
+                    )
+                ],
+            )
+            for i in range((len(state_combinations) // batch_size) + 1)
         )
 
+        weights_list = np.array(list(itertools.chain(*weights_list)))
         unique_weights, weights_indices = np.unique(
             weights_list, axis=0, return_inverse=True
         )
@@ -159,7 +222,6 @@ class BaseGradLogPDF(object):
     """
 
     def __init__(self, variable_assignments, model):
-
         self.variable_assignments = _check_1d_array_object(
             variable_assignments, "variable_assignments"
         )
@@ -317,7 +379,6 @@ class BaseSimulateHamiltonianDynamics(object):
     def __init__(
         self, model, position, momentum, stepsize, grad_log_pdf, grad_log_position=None
     ):
-
         position = _check_1d_array_object(position, "position")
 
         momentum = _check_1d_array_object(momentum, "momentum")
@@ -438,7 +499,6 @@ class LeapFrog(BaseSimulateHamiltonianDynamics):
     def __init__(
         self, model, position, momentum, stepsize, grad_log_pdf, grad_log_position=None
     ):
-
         BaseSimulateHamiltonianDynamics.__init__(
             self, model, position, momentum, stepsize, grad_log_pdf, grad_log_position
         )
@@ -517,7 +577,6 @@ class ModifiedEuler(BaseSimulateHamiltonianDynamics):
     def __init__(
         self, model, position, momentum, stepsize, grad_log_pdf, grad_log_position=None
     ):
-
         BaseSimulateHamiltonianDynamics.__init__(
             self, model, position, momentum, stepsize, grad_log_pdf, grad_log_position
         )
