@@ -1,11 +1,11 @@
 import unittest
 
-import pandas as pd
 import numpy as np
+import pandas as pd
 
+from pgmpy.estimators import ExpectationMaximization as EM
 from pgmpy.models import BayesianNetwork
 from pgmpy.sampling import BayesianModelSampling
-from pgmpy.estimators import ExpectationMaximization as EM
 from pgmpy.utils import get_example_model
 
 
@@ -22,14 +22,14 @@ class TestEMObserved(unittest.TestCase):
 
     def test_get_parameters(self):
         est = EM(self.model1, self.data1)
-        cpds = est.get_parameters(seed=42)
+        cpds = est.get_parameters(seed=42, show_progress=False)
         for est_cpd in cpds:
             var = est_cpd.variables[0]
             orig_cpd = self.model1.get_cpds(var)
             self.assertTrue(orig_cpd.__eq__(est_cpd, atol=0.1))
 
         est = EM(self.model2, self.data2)
-        cpds = est.get_parameters(seed=42)
+        cpds = est.get_parameters(seed=42, show_progress=False)
         for est_cpd in cpds:
             var = est_cpd.variables[0]
             orig_cpd = self.model2.get_cpds(var)
