@@ -2,8 +2,8 @@ import unittest
 
 import pandas as pd
 
+from pgmpy.estimators import AICScore, BDeuScore, BDsScore, BicScore, K2Score
 from pgmpy.models import BayesianNetwork
-from pgmpy.estimators import BDeuScore, BDsScore, BicScore, K2Score
 
 
 class TestBDeuScore(unittest.TestCase):
@@ -137,3 +137,37 @@ class TestK2Score(unittest.TestCase):
         del self.m2
         del self.titanic_data
         del self.titanic_data2
+
+
+class TestAICScore(unittest.TestCase):
+    def setUp(self):
+        self.d1 = pd.DataFrame(
+            data={"A": [0, 0, 1], "B": [0, 1, 0], "C": [1, 1, 0], "D": ["X", "Y", "Z"]}
+        )
+        self.m1 = BayesianNetwork([("A", "C"), ("B", "C"), ("D", "B")])
+        self.m2 = BayesianNetwork([("C", "A"), ("C", "B"), ("A", "D")])
+
+        # data_link - "https://www.kaggle.com/c/titanic/download/train.csv"
+        self.titanic_data = pd.read_csv(
+            "pgmpy/tests/test_estimators/testdata/titanic_train.csv"
+        )
+        self.titanic_data2 = self.titanic_data[["Survived", "Sex", "Pclass"]]
+
+    def test_score(self):
+        self.assertAlmostEqual(AICScore(self.d1).score(self.m1), -15.205379370888767)
+        self.assertEqual(AICScore(self.d1).score(BayesianNetwork()), 0)
+
+    def test_score_titanic(self):
+        scorer = AICScore(self.titanic_data2)
+        titanic = BayesianNetwork([("Sex", "Survived"), ("Pclass", "Survived")])
+        self.assertAlmostEqual(scorer.score(titanic), -1875.1594513603993)
+        titanic2 = BayesianNetwork([("Pclass", "Sex")])
+        titanic2.add_nodes_from(["Sex", "Survived", "Pclass"])
+        self.assertLess(scorer.score(titanic2), scorer.score(titanic))
+
+    def tearDown(self):
+        del self.d1
+        del self.m1
+        del self.m2
+        del self.titanic_data
+        del self.titanic_data2
